#include <atari.h>
#include <stdio.h>
#include <peekpoke.h>
#include <joystick.h>

#define SCREEN_SIZE 40
#define PADDLE_SIZE 6
#define PADDLE_Y 20

#define COLOR1 0x2C5
#define COLOR2 0x2C6
#define CDTMV3 0x21C
#define ATTRACT 0x4D

// 29 is '=' character in ANTIC character set
#define BRICK  29
#define PADDLE 213


// Global variables

unsigned char *video_ptr;
unsigned char total_bricks;
unsigned char paddle_pos=0;

// Joystick

extern char joy_driver;
unsigned char joy;

// Helper macros 
#define set_char(x,y,a) video_ptr[(x)+(y)*SCREEN_SIZE]=(a);
#define get_char(x,y) video_ptr[(x)+(y)*SCREEN_SIZE]

void set_colors()
{
	POKE(COLOR1,0xFF); // font color
	POKE(COLOR2,0);    // background color
}

void draw_bricks()
{
  for (total_bricks=0;total_bricks<4*SCREEN_SIZE;total_bricks++)
    video_ptr[total_bricks]=BRICK;
}

void draw_paddle()
{  
  register unsigned char s;
  for (s=0;s<PADDLE_SIZE;++s)
    set_char(s+paddle_pos,PADDLE_Y,PADDLE);
  set_char(paddle_pos-1,PADDLE_Y,0);
  set_char(paddle_pos+PADDLE_SIZE,PADDLE_Y,0);
}

int main(void)
{
  joy_install(&joy_driver);
  _graphics(0);
  set_colors();

  // get screen memory pointer
  video_ptr=(unsigned char*)(PEEKW( PEEKW(560)+4 ));
  draw_bricks();
	
  paddle_pos=(SCREEN_SIZE-PADDLE_SIZE)/2;

  for(;;)
  {
    // wait a moment and read the joystick state after that 
    POKE(CDTMV3,3);
    while(PEEK(CDTMV3));
    POKE(ATTRACT,0); // Disable Attract mode
    
    joy=joy_read(JOY_1);
    if (JOY_BTN_LEFT(joy))
    {
      if (paddle_pos>0)
        --paddle_pos;
    }
    if (JOY_BTN_RIGHT(joy))
    {
      if (paddle_pos<SCREEN_SIZE-PADDLE_SIZE)
        ++paddle_pos;
    }
    draw_paddle();
  }
  return 0;
}
